@@ -4,26 +4,6 @@
 Statistics related stuff in igraph
 """
 
-__license__ = """\
-Copyright (C) 2006-2012  Tamas Nepusz <ntamas@gmail.com>
-Pázmány Péter sétány 1/a, 1117 Budapest, Hungary
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc.,  51 Franklin Street, Fifth Floor, Boston, MA 
-02110-1301 USA
-"""
-
 import math
 
 __all__ = (
@@ -45,7 +25,8 @@ class FittedPowerLaw(object):
 
         >>> result = power_law_fit([1, 2, 3, 4, 5, 6])
         >>> result                   # doctest:+ELLIPSIS
-        FittedPowerLaw(continuous=False, alpha=2.42..., xmin=3.0, L=-7.54..., D=0.21..., p=0.993...)
+        FittedPowerLaw(continuous=False, alpha=2.42..., xmin=3.0, L=-7.54..., \
+D=0.21..., p=0.993...)
         >>> print(result)            # doctest:+ELLIPSIS
         Fitted power-law distribution on discrete data
         <BLANKLINE>
@@ -198,7 +179,6 @@ class Histogram(object):
         """Returns the mean of the elements in the histogram"""
         return self._running_mean.mean
 
-    # pylint: disable-msg=C0103
     @property
     def sd(self):
         """Returns the standard deviation of the elements in
@@ -355,7 +335,6 @@ class RunningMean(object):
     the fly)
     """
 
-    # pylint: disable-msg=C0103
     def __init__(self, items=None, n=0.0, mean=0.0, sd=0.0):
         """RunningMean(items=None, n=0.0, mean=0.0, sd=0.0)
 
